from .abc import (
    DiscoveryClient,
)
from .memory import (
    InMemoryDiscoveryClient,
)
